<?php

namespace Drupal\template_entities\Plugin\TemplatePlugin;

use Drupal;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Plugin\PluginWithFormsInterface;
use Drupal\template_entities\Entity\Template;

/**
 * Template plugin for nodes.
 *
 * This overrides the derived one but gets derived definition merged in
 * automatically.
 *
 * @TemplatePlugin(
 *   id = "canonical_entities:node",
 *   forms = {
 *     "create-template" =
 *   "Drupal\template_entities\PluginForm\NodeTemplate\CreateTemplateForm",
 *   }
 * )
 */
class NodeTemplate extends TemplatePluginBase implements DependentPluginInterface, PluginWithFormsInterface {

  /**
   * {@inheritdoc}
   */
  public function duplicateEntity(EntityInterface $entity, Template $template) {
    /** @var \Drupal\node\Entity\Node $duplicate_node */
    $duplicate_node = parent::duplicateEntity($entity, $template);

    $request_time = Drupal::time()
      ->getRequestTime();

    $duplicate_node->setCreatedTime($request_time);

    // Make current user the owner.
    $duplicate_node->setOwnerId(Drupal::currentUser()->id());

    return $duplicate_node;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    return [
      'module' => ['node'],
    ];
  }

}

